

class Trace:
    
    def __init__(self):
        pass
    
    def __repr__(self):
        return "Trace"
    
    
class StarTrace:
    
    def __init__(self):
        pass
    
    def __repr__(self):
        return "Stellar Trace"
    
class SkyTrace:
    
    def __init__(self):
        pass
    
    def __repr__(self):
        return "Stellar Trace"
    
class SparseTrace:
    
    def __init__(self):
        pass
    
    def __repr__(self):
        return "Sparse Line Trace"
    

class SlitFlatTrace:
    
    def __init__(self):
        pass
    
    def __repr__(self):
        return "Slit Flat Trace"